@@ -3,7 +3,7 @@ BEGIN {
   $Tapper::Benchmark::Query::SQLite::AUTHORITY = 'cpan:TAPPER';
 }
 # ABSTRACT: Tapper::Benchmark - qerying - SQLite backend
-$Tapper::Benchmark::Query::SQLite::VERSION = '0.002';
+$Tapper::Benchmark::Query::SQLite::VERSION = '0.003';
 use strict;
 use warnings;
 use feature 'switch';
@@ -639,7 +639,7 @@ sub insert_addtyperelation {
     my ( $or_self, @a_vals ) = @_;
 
     return $or_self->execute_query( "
-        INSERT INTO $or_self->{config}{tables}{additional_type_relation_table}
+        INSERT OR IGNORE INTO $or_self->{config}{tables}{additional_type_relation_table}
             ( bench_id, bench_additional_type_id, created_at )
         VALUES
             ( ?, ?, CURRENT_TIMESTAMP )
@@ -678,7 +678,7 @@ sub insert_benchmark_value {
     my ( $or_self, @a_vals ) = @_;
 
     return $or_self->execute_query( "
-        INSERT INTO $or_self->{config}{tables}{benchmark_value_table}
+        INSERT OR IGNORE INTO $or_self->{config}{tables}{benchmark_value_table}
             ( bench_id, bench_subsume_type_id, bench_value, active, created_at )
         VALUES
             ( ?, ?, ?, 1, CURRENT_TIMESTAMP )
@@ -792,7 +792,7 @@ sub insert_addvaluerelation {
     my ( $or_self, @a_vals ) = @_;
 
     return $or_self->execute_query( "
-        INSERT INTO $or_self->{config}{tables}{additional_relation_table}
+        INSERT OR IGNORE INTO $or_self->{config}{tables}{additional_relation_table}
             ( bench_value_id, bench_additional_value_id, active, created_at )
         VALUES
             ( ?, ?, 1, CURRENT_TIMESTAMP )
