@@ -3,7 +3,7 @@ BEGIN {
   $Tapper::Benchmark::Query::mysql::AUTHORITY = 'cpan:TAPPER';
 }
 # ABSTRACT: Tapper::Benchmark - qerying - MySQL backend
-$Tapper::Benchmark::Query::mysql::VERSION = '0.002';
+$Tapper::Benchmark::Query::mysql::VERSION = '0.003';
 use strict;
 use warnings;
 use feature 'switch';
@@ -636,7 +636,7 @@ sub insert_addtyperelation {
     my ( $or_self, @a_vals ) = @_;
 
     return $or_self->execute_query( "
-        INSERT INTO $or_self->{config}{tables}{additional_type_relation_table}
+        INSERT IGNORE INTO $or_self->{config}{tables}{additional_type_relation_table}
             ( bench_id, bench_additional_type_id, created_at )
         VALUES
             ( ?, ?, NOW() )
@@ -653,6 +653,8 @@ sub insert_unit {
             ( bench_unit, created_at )
         VALUES
             ( ?, NOW() )
+        ON DUPLICATE KEY
+            UPDATE bench_unit_id=LAST_INSERT_ID(bench_unit_id)
     ", @a_vals );
 
 }
@@ -666,6 +668,8 @@ sub insert_benchmark {
             ( bench, bench_unit_id, active, created_at )
         VALUES
             ( ?, ?, 1, NOW() )
+        ON DUPLICATE KEY
+            UPDATE bench_id=LAST_INSERT_ID(bench_id)
     ", @a_vals );
 
 }
@@ -675,7 +679,7 @@ sub insert_benchmark_value {
     my ( $or_self, @a_vals ) = @_;
 
     return $or_self->execute_query( "
-        INSERT INTO $or_self->{config}{tables}{benchmark_value_table}
+        INSERT IGNORE INTO $or_self->{config}{tables}{benchmark_value_table}
             ( bench_id, bench_subsume_type_id, bench_value, active, created_at )
         VALUES
             ( ?, ?, ?, 1, NOW() )
@@ -763,10 +767,12 @@ sub insert_addtype {
     my ( $or_self, @a_vals ) = @_;
 
     return $or_self->execute_query( "
-        INSERT INTO $or_self->{config}{tables}{additional_type_table}
+        INSERT IGNORE INTO $or_self->{config}{tables}{additional_type_table}
             ( bench_additional_type, created_at )
         VALUES
             ( ?, NOW() )
+        ON DUPLICATE KEY
+            UPDATE bench_additional_type_id=LAST_INSERT_ID(bench_additional_type_id)
     ", @a_vals );
 
 }
@@ -780,6 +786,8 @@ sub insert_addvalue {
             ( bench_additional_type_id, bench_additional_value, created_at )
         VALUES
             ( ?, ?, NOW() )
+        ON DUPLICATE KEY
+            UPDATE bench_additional_value_id=LAST_INSERT_ID(bench_additional_value_id)
     ", @a_vals );
 
 }
@@ -789,7 +797,7 @@ sub insert_addvaluerelation {
     my ( $or_self, @a_vals ) = @_;
 
     return $or_self->execute_query( "
-        INSERT INTO $or_self->{config}{tables}{additional_relation_table}
+        INSERT IGNORE INTO $or_self->{config}{tables}{additional_relation_table}
             ( bench_value_id, bench_additional_value_id, active, created_at )
         VALUES
             ( ?, ?, 1, NOW() )
